@@ -18,7 +18,6 @@ from django.core.files.storage import default_storage
 from django.core.files.base import ContentFile
 from django.utils.translation import ugettext_lazy as _
 
-
 from tendenci.core.base.http import Http403
 from tendenci.core.perms.decorators import is_enabled
 from tendenci.core.perms.utils import update_perms_and_save, get_notice_recipients, has_perm, get_query_filters, has_view_perm
@@ -205,7 +204,7 @@ def edit(request, id, form_class=ArticleForm,
 
                 # update all permissions and save the model
                 update_perms_and_save(request, form, article)
-                msg_string = 'Successfully updated %s' % article
+                msg_string = 'Successfully updated %s' % unicode(article)
                 messages.add_message(request, messages.SUCCESS, _(msg_string))
 
                 return HttpResponseRedirect(reverse('article', args=[article.slug]))
@@ -255,7 +254,7 @@ def edit_meta(request, id, form_class=MetaForm, template_name="articles/edit-met
         if form.is_valid():
             article.meta = form.save()  # save meta
             article.save()  # save relationship
-            msg_string = 'Successfully updated meta for %s' % article
+            msg_string = 'Successfully updated meta for %s' % unicode(article)
             messages.add_message(request, messages.SUCCESS, _(msg_string))
 
             return HttpResponseRedirect(reverse('article', args=[article.slug]))
@@ -289,7 +288,7 @@ def add(request, form_class=ArticleForm,
 
                 # add all permissions and save the model
                 update_perms_and_save(request, form, article)
-                msg_string = 'Successfully added %s' % article
+                msg_string = 'Successfully added %s' % unicode(article)
                 messages.add_message(request, messages.SUCCESS, _(msg_string))
 
                 # send notification to administrator(s) and module recipient(s)
@@ -327,7 +326,7 @@ def delete(request, id, template_name="articles/delete.html"):
 
     if has_perm(request.user, 'articles.delete_article'):
         if request.method == "POST":
-            msg_string = 'Successfully deleted %s' % article
+            msg_string = 'Successfully deleted %s' % unicode(article)
             messages.add_message(request, messages.SUCCESS, _(msg_string))
 
             # send notification to administrators
