@@ -12,6 +12,7 @@ from django.core.urlresolvers import reverse
 from django.db.models.fields import AutoField
 from django.template.loader import render_to_string
 from django.utils.encoding import smart_str
+from django.utils.translation import ugettext_lazy as _
 
 from tendenci.addons.directories.models import Directory, DirectoryPricing
 from tendenci.apps.invoices.models import Invoice
@@ -61,9 +62,9 @@ def get_duration_choices(user):
 
 def get_payment_method_choices(user):
     if user.profile.is_superuser:
-        return (('paid - check', 'User paid by check'),
-                ('paid - cc', 'User paid by credit card'),
-                ('Credit Card', 'Make online payment NOW'),)
+        return (('paid - check', _('User paid by check')),
+                ('paid - cc', _('User paid by credit card')),
+                ('Credit Card', _('Make online payment NOW')),)
     else:
         directory_payment_types = get_setting('module', 'directories', 'directoriespaymenttypes')
         if directory_payment_types:
