@@ -1,4 +1,5 @@
 from django.contrib import admin
+from django.utils.translation import ugettext_lazy as _
 
 from tendenci.core.perms.admin import TendenciBaseModelAdmin
 from tendenci.addons.resumes.models import Resume
@@ -10,7 +11,7 @@ class ResumeAdmin(TendenciBaseModelAdmin):
     prepopulated_fields = {'slug': ['title']}
     search_fields = ['title', 'description']
     fieldsets = (
-        ('Resume Information', {
+        (_('Resume Information'), {
             'fields': ('title',
                        'slug',
                        'description',
@@ -22,13 +23,13 @@ class ResumeAdmin(TendenciBaseModelAdmin):
                        'activation_dt',
                 )
         }),
-        ('Permissions', {'fields': ('allow_anonymous_view',)}),
-        ('Advanced Permissions', {'classes': ('collapse',), 'fields': (
+        (_('Permissions'), {'fields': ('allow_anonymous_view',)}),
+        (_('Advanced Permissions'), {'classes': ('collapse',), 'fields': (
             'user_perms',
             'member_perms',
             'group_perms',
             )}),
-        ('Status', {'fields': (
+        (_('Status'), {'fields': (
             'status_detail',
             )}),
         )
@@ -40,4 +41,4 @@ class ResumeAdmin(TendenciBaseModelAdmin):
       FormModel.user = request.user
       return FormModel
 
-admin.site.register(Resume, ResumeAdmin)
\ No newline at end of file
+admin.site.register(Resume, ResumeAdmin)
