@@ -1,4 +1,5 @@
 from django.conf import settings
+from django.utils.translation import ugettext_lazy as _
 
 from tendenci.core.registry import site
 from tendenci.core.registry.base import CoreRegistry, lazy_reverse
@@ -7,9 +8,9 @@ from tendenci.apps.redirects.models import Redirect
 
 class RedirectRegistry(CoreRegistry):
     version = '1.0'
-    author = 'Schipul - The Web Marketing Company'
+    author = _('Schipul - The Web Marketing Company')
     author_email = 'programmers@schipul.com'
-    description = 'Add redirects to preserve SEO'
+    description = _('Add redirects to preserve SEO')
     icon = '%simages/icons/redirects-color-64x64.png' % settings.STATIC_URL
 
     url = {
